@@ -44,9 +44,11 @@ QString Ethernet2Frame::sourceAddress() const
   {
     struct ether_header *eth = (struct ether_header *) m_packet->getPacket();
 
-    return QString("%1:%2:%3:%4:%5:%6").arg(eth->ether_shost[0], 0, 16).arg(eth->ether_shost[1], 0, 16)
-        .arg(eth->ether_shost[2], 0, 16).arg(eth->ether_shost[3], 0, 16).arg(eth->ether_shost[4], 0, 16)
-        .arg(eth->ether_shost[5], 0, 16);
+    QString mac = QString("%1:%2:%3:%4:%5:%6").arg(eth->ether_shost[0], 2, 16).arg(eth->ether_shost[1], 2, 16)
+        .arg(eth->ether_shost[2], 2, 16).arg(eth->ether_shost[3], 2, 16).arg(eth->ether_shost[4], 2, 16)
+        .arg(eth->ether_shost[5], 2, 16);
+    mac.replace(" ", "0");
+    return mac;
   }
   else
     return QString::null;
@@ -59,9 +61,11 @@ QString Ethernet2Frame::destinationAddress() const
   {
     struct ether_header *eth = (struct ether_header *) m_packet->getPacket();
 
-    return QString("%1:%2:%3:%4:%5:%6").arg(eth->ether_dhost[0], 0, 16).arg(eth->ether_dhost[1], 0, 16)
-        .arg(eth->ether_dhost[2], 0, 16).arg(eth->ether_dhost[3], 0, 16).arg(eth->ether_dhost[4], 0, 16)
-        .arg(eth->ether_dhost[5], 0, 16);
+    QString mac = QString("%1:%2:%3:%4:%5:%6").arg(eth->ether_dhost[0], 2, 16).arg(eth->ether_dhost[1], 2, 16)
+        .arg(eth->ether_dhost[2], 2, 16).arg(eth->ether_dhost[3], 2, 16).arg(eth->ether_dhost[4], 2, 16)
+        .arg(eth->ether_dhost[5], 2, 16);
+    mac.replace(" ", "0");
+    return mac;
   }
   else
     return QString::null;
@@ -75,11 +79,15 @@ QStringList Ethernet2Frame::headerLines() const
   if (m_packet)
   {
     struct ether_header *eth = (struct ether_header *) m_packet->getPacket();
-    list << i18n("Ethernet2 Frame Field", "MAC Source Address: %1:%2:%3:%4:%5:%6").arg(eth->ether_shost[0], 0, 16).arg(eth->ether_shost[1], 0, 16)
-        .arg(eth->ether_shost[2], 0, 16).arg(eth->ether_shost[3], 0, 16).arg(eth->ether_shost[4], 0, 16)
-        .arg(eth->ether_shost[5], 0, 16);
-    list << i18n("Ethernet2 Frame Field", "MAC Destination Address: %1:%2:%3:%4:%5:%6").arg(eth->ether_dhost[0], 0, 16).arg(eth->ether_dhost[1], 0, 16)
-        .arg(eth->ether_dhost[2], 0, 16).arg(eth->ether_dhost[3], 0, 16).arg(eth->ether_dhost[4], 0, 16).arg(eth->ether_dhost[5], 0, 16);
+    QString mac = QString("%1:%2:%3:%4:%5:%6").arg(eth->ether_shost[0], 2, 16).arg(eth->ether_shost[1], 2, 16)
+        .arg(eth->ether_shost[2], 2, 16).arg(eth->ether_shost[3], 2, 16).arg(eth->ether_shost[4], 2, 16)
+        .arg(eth->ether_shost[5], 2, 16);
+    mac.replace(" ", "0");
+    list << i18n("Ethernet2 Frame Field", "MAC Source Address: %1").arg(mac);
+    mac = QString("%1:%2:%3:%4:%5:%6").arg(eth->ether_dhost[0], 2, 16).arg(eth->ether_dhost[1], 2, 16)
+        .arg(eth->ether_dhost[2], 2, 16).arg(eth->ether_dhost[3], 2, 16).arg(eth->ether_dhost[4], 2, 16).arg(eth->ether_dhost[5], 2, 16);
+    mac.replace(" ", "0");
+    list << i18n("Ethernet2 Frame Field", "MAC Destination Address: %1").arg(mac);
     list << i18n("Ethernet2 Frame Field", "Protocol Type: 0x%1").arg(htons(eth->ether_type), 0, 16);
   }
 
