@@ -24,15 +24,9 @@
 #include <signal.h>
 
 #include <qstring.h>
-#include <qpopupmenu.h>
-#include <qdragobject.h>
-#include <qpainter.h>
-#include <qpaintdevicemetrics.h>
 #include <qtooltip.h>
-#include <qfile.h>
-#include <qtextstream.h>
 #include <qtimer.h>
-#include <qdom.h>
+#include <qsplashscreen.h>
 
 #include <kuniqueapplication.h>
 #include <kprinter.h>
@@ -68,7 +62,7 @@
 #include "ksniffer.h"
 #include "capturedialog.h"
 #include "options/ksnifferoptiondialog.h"
-#include "protocols/protocolname.h"
+#include "protocols/protocolnamelist.h"
 #include "sniffer.h"
 #include "packetmanager.h"
 #include "packet.h"
@@ -101,8 +95,28 @@ KSniffer::KSniffer()
   // set into m_options the available options directly from the ksnifferrc configuration file
   readSettings();
 
+  // prepare the Splash screen to show if needed
+  QSplashScreen *splash = 0;
+  if (m_options->showSplash())
+  {
+    QString splashFile = locate("appdata", "pics/splash.png");
+    if (!splashFile.isEmpty())
+    {
+      QPixmap pm;
+      pm.load(splashFile);
+      splash = new QSplashScreen( pm );
+      splash->show();
+      qApp->processEvents();
+      sleep(1); // a small delay to look at the splash screen
+      splash->finish(m_mainWidgetUI);
+    }
+  }
+
+  m_protocolNameList = new ProtocolNameList();
+
   // set the view widget configuration
   m_mainWidgetUI->setOptions( m_options );
+  m_mainWidgetUI->setProtocolNameList( m_protocolNameList );
 
   // option just assigned
   m_optionChanged = false;
@@ -143,34 +157,34 @@ KSniffer::KSniffer()
 
   // Setting System tray icon if needed
   // prepare all the stuff for the show/hide tray bar...
-    m_sysTray = new KSystemTray( this );
-    m_sysTray->setTextFormat( Qt::RichText );
-    m_sysTray->setPixmap( m_sysTray->loadIcon( "ksniffer" ) );
-    QToolTip::add( m_sysTray, QString( "KSniffer " ) + APPVER );
-    connect( m_sysTray, SIGNAL(quitSelected()), SLOT(slotQuit()) );
+  m_sysTray = new KSystemTray( this );
+  m_sysTray->setTextFormat( Qt::RichText );
+  m_sysTray->setPixmap( m_sysTray->loadIcon( "ksniffer" ) );
+  QToolTip::add( m_sysTray, QString( "KSniffer " ) + APPVER );
+  connect( m_sysTray, SIGNAL(quitSelected()), SLOT(slotQuit()) );
 
-    // Sub menu: "Capture" item
-    KPopupMenu *popupCapture = new KPopupMenu ( this );
+  // Sub menu: "Capture" item
+  KPopupMenu *popupCapture = new KPopupMenu ( this );
 
-    // the subitems...
-    m_actNew->plug( popupCapture );
-    m_actOpen->plug( popupCapture );
-    m_actSave->plug( popupCapture );
-    m_actSaveAs->plug( popupCapture );
-    m_actPauseContinue->plug( popupCapture );
-    m_actStop->plug( popupCapture );
-    m_actPrint->plug( popupCapture );
+  // the subitems...
+  m_actNew->plug( popupCapture );
+  m_actOpen->plug( popupCapture );
+  m_actSave->plug( popupCapture );
+  m_actSaveAs->plug( popupCapture );
+  m_actPauseContinue->plug( popupCapture );
+  m_actStop->plug( popupCapture );
+  m_actPrint->plug( popupCapture );
 
-    m_sysTray->contextMenu()->insertItem( i18n("&Capture"), popupCapture, 0, 1 );
+  m_sysTray->contextMenu()->insertItem( i18n("&Capture"), popupCapture, 0, 1 );
 
-    // Sub menu: "Help" item
-    KPopupMenu *popupHelp = helpMenu();
-    m_sysTray->contextMenu()->insertItem ( i18n("&Help"), popupHelp, 0, 2 );
+  // Sub menu: "Help" item
+  KPopupMenu *popupHelp = helpMenu();
+  m_sysTray->contextMenu()->insertItem ( i18n("&Help"), popupHelp, 0, 2 );
 
-    // KSniffer settings
-    KAction *preferences = KStdAction::preferences(this, SLOT(optionsSettings()), actionCollection());
-    m_sysTray->contextMenu()->insertSeparator( 3 );
-    preferences->plug( m_sysTray->contextMenu(), 4 );
+  // KSniffer settings
+  KAction *preferences = KStdAction::preferences(this, SLOT(optionsSettings()), actionCollection());
+  m_sysTray->contextMenu()->insertSeparator( 3 );
+  preferences->plug( m_sysTray->contextMenu(), 4 );
 
     // ...now show tray bar if needed
   if (m_showTrayBar)
@@ -191,6 +205,10 @@ KSniffer::KSniffer()
 
   m_timer = new QTimer(this);
   connect( m_timer, SIGNAL(timeout()), this, SLOT(checkIfSniffing()));
+
+  // delete the splash if it's been used
+  if (splash)
+    delete splash;
 }
 
 
@@ -206,6 +224,7 @@ KSniffer::~KSniffer()
   delete m_mainWidgetUI;
   delete m_actOpenRecent;
   delete m_timer;
+  delete m_protocolNameList;
 }
 
 void KSniffer::load(const KURL& url)
@@ -409,7 +428,7 @@ void KSniffer::readSettings()
   m_actOpenRecent->setEnabled( true ); // force enabling
   m_actOpenRecent->setToolTip( i18n("Click to open a file\nClick and hold to open a recent file") );
 
-  // set into m_options the sniffer options (ShowAfter, TrayBar, TmpDirectory, Warn, PassivePopUp)
+  // set into m_options the sniffer options (ShowAfter, TrayBar, TmpDirectory, Warn, PassivePopUp, ShowSplash)
   m_snifferOption->getOptions( m_options );
 
   m_mustShowPacketsNow = !m_options->showAfter();
@@ -457,7 +476,9 @@ bool KSniffer::queryClose()
   if (!m_showTrayBar)
   {
     slotQuit();
-    if ((m_action & ACT_QUIT_APPL) == ACT_QUIT_APPL)
+
+    // the application can exit just if it has not to save the data file
+    if (((m_action & ACT_QUIT_APPL) == ACT_QUIT_APPL) && (m_action & ACT_SAVING_PACKETS) != ACT_SAVING_PACKETS)
       return true;
     else
       return false;
@@ -554,7 +575,7 @@ void KSniffer::slotNewCapture()
     startLiveSniffing( cod->selectedInterface() );
   }
   else
-    changeStatusbar( i18n("Ready.") );
+    readyStatusbar();
 
   delete cod;
 }
@@ -582,6 +603,11 @@ void KSniffer::slotOpen( const KURL& urlParam )
     }
     else
       url0 = urlParam;
+    if (url0.isEmpty())
+    {
+      // no file to open
+      return;
+    }
     url = url0;  // real URL on which operate: to have always a local file
     kdDebug() << "File to open: " << url.prettyURL() << endl;
     QFile file( url.path() );
@@ -698,7 +724,7 @@ void KSniffer::slotOpen( const KURL& urlParam )
     else
       result = Sniffer::NO_FILE_SELECTED;
   } while ((result != Sniffer::RIGHT_FORMAT_FILE) && (result != Sniffer::NO_FILE_SELECTED));
-  changeStatusbar( i18n("Ready.") );
+  readyStatusbar();
 
   if ( (result != Sniffer::NO_FILE_SELECTED) && (result == Sniffer::RIGHT_FORMAT_FILE) )
   {
@@ -758,6 +784,9 @@ void KSniffer::slotSave()
     connect( job, SIGNAL( result(KIO::Job *) ),
              this, SLOT( copyingJobFinished(KIO::Job *) ) );
 
+    if ( job->error() )
+        job->showErrorDialog( this );
+
     // set the title for the saved filename
     m_strSavedFilename = dest;
   }
@@ -784,6 +813,9 @@ void KSniffer::slotSaveAs()
       connect( job, SIGNAL( result(KIO::Job *) ),
                this, SLOT( copyingJobFinished(KIO::Job *) ) );
 
+      if ( job->error() )
+        job->showErrorDialog( this );
+
       // set the title for the saved filename
       m_strSavedFilename = dest;
       m_actOpenRecent->addURL( dest );
@@ -841,6 +873,9 @@ void KSniffer::slotPauseContinue()
     m_actPauseContinue->setWhatsThis( m_whatsthisPause );
     m_actPauseContinue->setText( i18n("&Pause Capture") );
     m_sniffProcess->kill(SIGUSR1);
+    if (!m_options->showAfter())
+      // just if the show packet is in real time you need to enable the view for the update
+      m_mainWidgetUI->startSniffing();
   }
   else
   {
@@ -853,6 +888,7 @@ void KSniffer::slotPauseContinue()
     m_actPauseContinue->setWhatsThis( i18n("<b>Continue Capture</b><br>Continue the paused packet-capture.") );
     m_actPauseContinue->setText( i18n("&Continue Capture") );
     m_sniffProcess->kill(SIGUSR1);
+    m_mainWidgetUI->stopSniffing();
   }
 }
 
@@ -936,7 +972,7 @@ void KSniffer::slotStop()
           KSnifferPassivePopup::message( i18n("Capturing"), i18n("<p>You got no packets.</p>"), this );
         else
           KMessageBox::information(this, i18n("You got no packets."));
-        changeStatusbar(i18n("Ready."));
+        readyStatusbar();
       }
       m_actSave->setEnabled( false );
       m_actSaveAs->setEnabled( false );
@@ -989,10 +1025,14 @@ void KSniffer::stopSniffing()
   // the thread has a little delay to stop, so before
   // to start a new thread the last has to be finished
   if ( (!m_mustShowPacketsNow) && (m_sniffer->countPackets() > 0) )
+  {
     // check just if you have to display packets after you stopped the capture
     // and if you captured at least 1 packet (just in this case the thread starts)
     while (m_sniffer->running())
       usleep(1000);
+  }
+  // tell the GUI that the siffing process has stopped
+  m_mainWidgetUI->stopSniffing();
 }
 
 
@@ -1041,6 +1081,7 @@ void KSniffer::showAfterDisplay( const KURL& url )
 
 void KSniffer::checkIfSniffing()
 {
+  kdDebug() << "void KSniffer::checkIfSniffing()" << endl;
   if (!m_sniffer->isSniffing())
   {
     // if you want you can load a new file or start a new capture session
@@ -1064,7 +1105,7 @@ void KSniffer::checkIfSniffing()
 
     m_timer->stop();
 
-    kdDebug() << "ok the file was loaded" << endl;
+    kdDebug() << "ok the file was full loaded" << endl;
 
     // no need to save a loaded file...
     m_actSave->setEnabled( false );
@@ -1078,12 +1119,13 @@ void KSniffer::checkIfSniffing()
     {
       KSnifferPassivePopup::message( i18n("Loading file"), i18n("<p>Ok, the packets has gotten from the file.</p>"), this );
       changeStatusbar( i18n("Packets captured from file. Now, ready again.") );
+      QTimer::singleShot(2000, this, SLOT(readyStatusbar()));
     }
     else
     {
       KSnifferPassivePopup::message( i18n("Displaying captured packets"),
         i18n("<p>Ok, the captured packets are all in the list.</p>"), this );
-      changeStatusbar( i18n("Ready.") );
+      readyStatusbar();
 
       // enable it when packets have been read
       m_actSave->setEnabled( true );
@@ -1093,6 +1135,9 @@ void KSniffer::checkIfSniffing()
       m_startedShowing = false;
     }
     m_packets->acceptPacket( false );
+
+    // update the view if it's needed: if has to be applyed a view filter
+    m_mainWidgetUI->updateView();
   }
   else
   {
@@ -1127,7 +1172,13 @@ void KSniffer::slotQuit()
 
     // we have some data that maybe we want to save
     if ( button == KMessageBox::Yes )
+    {
+      // stop sniffing
+      stopSniffing();
+
+      // save sniffed session
       slotSave();
+    }
     else if ( button == KMessageBox::Cancel )
     {
       // ok the user don't want to quit KSniffer anymore
@@ -1137,8 +1188,7 @@ void KSniffer::slotQuit()
       return;
     }
     else
-      // quitting without saving data, so...
-      // ...stop really sniffing and...
+      // quitting from KSniffer without saving data: stop sniffing
       stopSniffing();
   }
 
@@ -1169,6 +1219,7 @@ void KSniffer::slotQuit()
 // decide what to do when the Job is finished
 void KSniffer::copyingJobFinished( KIO::Job *job )
 {
+  kdDebug() << "void KSniffer::copyingJobFinished( KIO::Job *job )" << endl;
   if (job->error() == 0)
   {
     // no error happened
@@ -1193,6 +1244,8 @@ void KSniffer::copyingJobFinished( KIO::Job *job )
       unlink( m_options->tmpFileConfigPath() );
     }
   }
+  else
+    job->showErrorDialog( this );
 }
 
 
@@ -1265,6 +1318,12 @@ void KSniffer::changeCaption( const QString& text )
 }
 
 
+void KSniffer::readyStatusbar()
+{
+  statusBar()->message( i18n("Ready.") );
+}
+
+
 void KSniffer::showTrayBar( bool show)
 {
   if ( show )
@@ -1277,6 +1336,7 @@ void KSniffer::showTrayBar( bool show)
     // hide the tray bar
     m_sysTray->hide();
   }
+  m_showTrayBar = show;
 }
 
 
@@ -1449,7 +1509,7 @@ void KSniffer::startLiveSniffing( const QString& interface )
 
   prepareXMLConfigFile();
   m_sniffProcess = new KProcess;
-  *m_sniffProcess << "sniff";
+  *m_sniffProcess << "ksniff";
   *m_sniffProcess << m_options->tmpFileConfigPath();
   connect(m_sniffProcess, SIGNAL(processExited(KProcess *)), this, SLOT(slotStop()));
   m_sniffProcess->start();
@@ -1475,7 +1535,7 @@ void KSniffer::startSniffingFromFile()
 
   m_sniffer->startSniffing();
 
-  //FIXME: timer still useful with the new sniffing method?
+  // starting loading a file we need to know when it stops so we check periodically
   m_timer->start(700);
 }
 
