@@ -40,10 +40,13 @@ class KSnifferMainWidget;
 class KSystemTray;
 class KTempFile;
 class KProcess;
+class PacketManager;
 
 class QString;
 class QTimer;
 
+class ProtocolNameList;
+
 /**
  * This class serves as the main window for KSniffer. It handles the
  * menus, toolbars, and status bars.
@@ -120,8 +123,8 @@ private slots:
   void slotQuit();
 
   /**
-   * check if the sniffing is ended or not and if it is do some staff
-   * enabling/disabling command and related icons
+   * check if the sniffing is ended or if you are still loading a file, so it can
+   * enable/disable command and related icons
    */
   void checkIfSniffing();
 
@@ -135,6 +138,7 @@ private slots:
 
   void changeStatusbar( const QString& text );
   void changeCaption( const QString& text );
+  void readyStatusbar();
 
   // show and hide the tray bar
   void showTrayBar( bool );
@@ -171,6 +175,7 @@ private:
   bool m_doingCapture;                  // true if it's sniffing
   bool m_doingPause;                    // true if capture is in pause
 
+  ProtocolNameList *m_protocolNameList;
   Sniffer *m_sniffer;
   CaptureOptions *m_options;
   SnifferOptionTab *m_snifferOption;
