@@ -32,6 +32,7 @@
 #include <qtoolbutton.h>
 #include <qtimer.h>
 #include <qpoint.h>
+#include <qtextedit.h>
 
 #include <kurl.h>
 #include <kiconloader.h>
@@ -66,10 +67,10 @@ KSnifferMainWidget::KSnifferMainWidget( QWidget* parent, const char* name )
   m_mainViewLayout->setAlignment( Qt::AlignTop );
 
   // splitter widget
-  m_splitter = new QSplitter( QSplitter::Vertical, this, "splitter" );
+  QSplitter *vertSplitter = new QSplitter( QSplitter::Vertical, this, "vertSplitter" );
 
   // packets listview widget
-  m_list = new KListView( m_splitter, "m_list" );
+  m_list = new KListView( vertSplitter, "m_list" );
   m_list->addColumn( i18n( "frame number", "Frame No." ) );
   m_list->addColumn( i18n( "Time" ) );
   m_list->addColumn( i18n( "Source" ) );
@@ -85,8 +86,11 @@ KSnifferMainWidget::KSnifferMainWidget( QWidget* parent, const char* name )
   // disable clicking on "Information"
   //m_list->header()->setClickEnabled( false, 5 );
 
+  // splitter widget
+  QSplitter *horizSplitter = new QSplitter( QSplitter::Horizontal, vertSplitter, "horizSplitter" );
+
   // packets details listview widget
-  m_detail = new QListView( m_splitter, "m_detail" );
+  m_detail = new QListView( horizSplitter, "m_detail" );
   KIconLoader kil;
   m_detail->addColumn( kil.loadIconSet("ksniffer", KIcon::Small), i18n( "Packet Details" ) );
 
@@ -95,6 +99,17 @@ KSnifferMainWidget::KSnifferMainWidget( QWidget* parent, const char* name )
   m_detail->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)3, 0, 0,
     m_detail->sizePolicy().hasHeightForWidth() ) );
 
+  m_rawPacketArea = new QTextEdit( horizSplitter, "rawbyte" );
+  QToolTip::add( m_rawPacketArea, i18n( "Show raw packet content" ) );
+  QWhatsThis::add( m_rawPacketArea, i18n( "In this area you will see the bytes contained by a network "
+      "packet when you click on it from the packet list." ) );
+
+  m_rawPacketArea->hide();  // show this widget when you click onto a packet from the list
+  QFont mono( "Monospace" );
+  m_rawPacketArea->setFont( mono );
+  QFontMetrics fm( mono );
+  m_rawPacketArea->setFixedWidth( fm.width("Z")*22 );
+
   // search line
   QToolButton* toolbtn = new QToolButton( this );
   toolbtn->setIconSet( SmallIconSet( QApplication::reverseLayout() ? "clear_left" : "locationbar_erase" ) );
@@ -122,7 +137,7 @@ KSnifferMainWidget::KSnifferMainWidget( QWidget* parent, const char* name )
 
   // add to layout
   m_mainViewLayout->addLayout( hLayout );
-  m_mainViewLayout->addWidget( m_splitter );
+  m_mainViewLayout->addWidget( vertSplitter );
 
   // we don't need sorting detail
   m_detail->setSortColumn(-1);
@@ -180,6 +195,9 @@ KSnifferMainWidget::KSnifferMainWidget( QWidget* parent, const char* name )
 
   // setting up the popup menu when click RMB on the packet list
   m_popupMenu = m_info->createPopupMenu();
+
+  m_timer = new QTimer();
+  connect(m_timer, SIGNAL(timeout()), this, SLOT(updateView()));
 }
 
 
@@ -248,6 +266,21 @@ void KSnifferMainWidget::setCollapse( QListViewItem* i )
 void KSnifferMainWidget::applyNewSearchFilter( const QString & text )
 {
   m_needToUpdateSearch = ( !text.isEmpty() );
+
+  // we need to enable the timer if view need to be upadated, has to show data and the time is not yet enabled
+  if (m_needToUpdateSearch)
+  {
+    if ((!m_options->showAfter()) && (!m_timer->isActive()))
+      m_timer->start(TIME_WAITING_UPDATE);
+  }
+  else
+  {
+    // no more need to update the view if the filter was resetted
+    m_timer->stop();
+    m_mutex.lock();
+    m_listSearch->updateSearch();
+    m_mutex.unlock();
+  }
 }
 
 
@@ -255,6 +288,7 @@ void KSnifferMainWidget::clearView()
 {
   m_list->clear();
   m_detail->clear();
+  m_rawPacketArea->hide();
 }
 
 
@@ -282,6 +316,12 @@ void KSnifferMainWidget::setOptions( CaptureOptions *options )
 }
 
 
+void KSnifferMainWidget::setProtocolNameList( ProtocolNameList *pnl )
+{
+  m_protocolNameList = pnl;
+}
+
+
 void KSnifferMainWidget::loadFromFile( bool load )
 {
   m_loadFromFile = load;
@@ -300,6 +340,48 @@ bool KSnifferMainWidget::displayingPacket()
 }
 
 
+void KSnifferMainWidget::updateFilter()
+{
+  kdDebug() << "updating the filter view: " << m_needToUpdateSearch << endl;
+  if (m_needToUpdateSearch)
+    // update the view by the filter if really needed
+    m_listSearch->updateSearch();
+}
+
+
+void KSnifferMainWidget::startSniffing()
+{
+  kdDebug() << "void KSnifferMainWidget::startSniffing()+++++++++++++++++" << endl;
+  if (!m_options->showAfter())
+    // just if the show packet is in real time you need to enable the view for the update
+    if (m_needToUpdateSearch)
+      m_timer->start(TIME_WAITING_UPDATE);
+}
+
+
+void KSnifferMainWidget::stopSniffing()
+{
+  // to stop sniffing the GUI has to update the view and stop the timer
+  updateFilter();
+  kdDebug() << "stopping the timer..." << endl;
+  m_timer->stop();
+}
+
+
+void KSnifferMainWidget::updateView()
+{
+  // when you load a file you have to appy this updateView at the end of the load
+  kdDebug() << "void KSnifferMainWidget::updateView()" << endl;
+  if (m_needToUpdateSearch)
+  {
+    m_mutex.lock();
+    m_listSearch->updateSearch();
+    m_mutex.unlock();
+    kdDebug() << "mutex" << endl;
+  }
+}
+
+
 void KSnifferMainWidget::displayPacket(long ord, PacketManager *pktMan)
 {
   // if the packets have to be displayed when captured or the
@@ -321,16 +403,17 @@ void KSnifferMainWidget::displayPacket(long ord, PacketManager *pktMan)
     {
       m_lastElem = new KSnifferViewItem( m_list, m_lastElem, pktMan );
     }
-    if (!m_loadFromFile)
-      // if you are getting packets from file you can't apply filter
-      // or the loading will be too slow
-      if (m_needToUpdateSearch)
-        m_listSearch->updateSearch();
   }
 
   // we need to save PacketManager class reference first time
   if (ord == 1)
+  {
     m_packetManager = pktMan;
+
+    // if the the capture is not from file than start the thread
+    if (!m_loadFromFile)
+      startSniffing();
+  }
 }
 
 
@@ -405,7 +488,7 @@ void KSnifferMainWidget::showDetails( QListViewItem * item )
           subitemFrame2 = new QListViewItem( itemFrame2, subitemFrame2, *it );
       }
 
-      ProtocolManager pm(m_packetManager->getPacket(), fpm.getSubProtocol());
+      ProtocolManager pm(m_packetManager->getPacket(), fpm.getSubProtocol(), m_protocolNameList);
       list = pm.headerLines();
       if (!list.isEmpty())
       {
@@ -430,6 +513,26 @@ void KSnifferMainWidget::showDetails( QListViewItem * item )
     }
   }
 
+  // show raw packet area
+  m_rawPacketArea->show();
+  ptrPacketType pkt = m_packetManager->getPacket();
+  QString packetOut;
+  int length = m_packetManager->packetSize();
+  int i = 0;
+  while (i < length)
+  {
+    if ((pkt[i] >= ' ') && (pkt[i] <= '~'))
+      packetOut += pkt[i];
+    else
+      packetOut += '.';
+    i++;
+    if (i % 16 == 0)
+      packetOut += "\n";
+    else if (i % 8 == 0)
+      packetOut += "  ";
+  }
+  m_rawPacketArea->setText( packetOut );
+
   // expand item lines if needed
   if (m_bExpanding0)
     itemFrame0->setOpen(true);
@@ -468,12 +571,12 @@ void KSnifferMainWidget::clickedMouseButton(QListViewItem* item, const QPoint& p
   switch (column)
   {
     case 2:
+      // source address
       ip = item->text(column);
-      kdDebug() << "+++++++++++++ source address: " << ip << endl;
       break;
     case 3:
+      // destination address
       ip = item->text(column);
-      kdDebug() << "+++++++++++++ destination address: " << ip << endl;
       break;
     default:
       ip = "";
