@@ -27,7 +27,10 @@
 #define WIDTH_COL_4 80
 #define WIDTH_COL_5 550
 
+#define TIME_WAITING_UPDATE 1000
+
 #include <qwidget.h>
+#include <qmutex.h>
 
 /**
  * This class contains the stuff to create and manage the QListView containing the
@@ -36,12 +39,13 @@
  * @author Giovanni Venturi
  */
 
-class QSplitter;
 class QListView;
 class QListViewItem;
 class QString;
 class QVBoxLayout;
 class QPoint;
+class QTextEdit;
+class QTimer;
 
 class KListView;
 class KURL;
@@ -49,6 +53,7 @@ class KListViewSearchLine;
 class KSnifferViewItem;
 class KInfoIP;
 
+class ProtocolNameList;
 class PacketManager;
 class CaptureOptions;
 
@@ -92,6 +97,8 @@ public:
 
   void setOptions( CaptureOptions *options );
 
+  void setProtocolNameList( ProtocolNameList *pnl );
+
   void loadFromFile( bool load = true );
 
   /**
@@ -104,6 +111,27 @@ public:
    */
   bool displayingPacket();
 
+  /**
+   * Update the filter list
+   */
+  void updateFilter();
+
+  /**
+   * Say yo the view the sniffing is starting
+   */
+  void startSniffing();
+
+  /**
+   * Say to the view the sniffing is stopping
+   */
+  void stopSniffing();
+
+public slots:
+  /**
+    * Say to upgrade the view: you need it when you loaded file and you should apply a view filter
+   */
+  void updateView();
+
 signals:
   /**
    * Use this signal to change the content of the statusbar
@@ -115,12 +143,14 @@ signals:
    */
   void signalChangeCaption(const QString& text);
 
-
 private:
-  QSplitter* m_splitter;
   KListView* m_list;
   QListView* m_detail;
   KListViewSearchLine *m_listSearch;
+  QTextEdit *m_rawPacketArea;
+  QTimer *m_timer;
+  QMutex m_mutex;
+
   bool m_needToUpdateSearch;     // true if there is text in the search line
   bool m_loadFromFile;     // true if you gets packets from file
   bool m_bExpanding0;      // true if the detail line 0 has to be expanded
@@ -128,19 +158,18 @@ private:
 
   KInfoIP *m_info;
   KPopupMenu *m_popupMenu;
-
-protected:
-  QVBoxLayout* m_mainViewLayout;
-
-private:
   bool m_firstInsert;              // true if we have to insert the first element into the list
   KSnifferViewItem *m_lastElem;    // point to the last element inserted into the list
   PacketManager *m_packetManager;  // needed to get and display all packet details
   CaptureOptions *m_options;
+  ProtocolNameList *m_protocolNameList;
 
   bool m_displayingPacket;  // true = captured packet has to be displayed into the view
                             // false = captured packet has NOT to be displayed into the view
 
+protected:
+  QVBoxLayout* m_mainViewLayout;
+
 private slots:
   void slotOnURL(const QString& url);
   void slotSetTitle(const QString& title);
