@@ -27,6 +27,7 @@
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kstandarddirs.h>
 
 #include "ksniffer.h"
 #include "version.h"
@@ -49,18 +50,39 @@ int main(int argc, char **argv)
   //about.addAuthor( "Giovanni Venturi", 0, "giovanni@ksniffer.org" );
   about.addAuthor( "Giovanni Venturi", I18N_NOOP("Original author and core developer"), "giovanni@ksniffer.org", "http://www.ksniffer.org/" );
   about.addCredit( "Alexander Neundorf", I18N_NOOP("The code for detecting network devices"), "neundorf@kde.org" );
-  about.addCredit( "Bram Schoenmakers", I18N_NOOP("Some patches and fixes"), "bramschoenmakers@kde.nl" );
   about.addCredit( I18N_NOOP("Gerald Combs and all Ethereal authors"),
     I18N_NOOP("A good sniffer application has to take a look at this great huge application"), "", "http://www.ethereal.com/" );
-  about.addCredit( "Luigi Toscano", I18N_NOOP("Testing, supporting, the code to stop capture in safe way"),
-    "luigi.toscano@tiscali.it" );
-  about.addCredit( "Pino Toscano", I18N_NOOP("Testing, supporting, good patches and ideas"),
-    "toscano.pino@tiscali.it" );
+  about.addCredit( "Carmine De Rosa", I18N_NOOP("KSniffer icon and splash screen"), "dslaky@gmail.com");
 
   KCmdLineArgs::init(argc, argv, &about);
   KCmdLineArgs::addCmdLineOptions(options);
   KUniqueApplication app;
 
+  // libpcap library to sniff network needs root privileges
+  struct stat statbuf;
+  QString ksniffPath = KStandardDirs::findExe("ksniff");
+  if (ksniffPath.isEmpty())
+  {
+    KMessageBox::sorry(0L, i18n("<p>The 'ksniff' executable was not found in your PATH<br>"
+        "environment. You need it to capture packets.<br><br>" \
+        "Your installation is not correct.</p>"));
+    return -1;
+  }
+
+  if (lstat(ksniffPath.ascii(), &statbuf) == -1)
+  {
+    KMessageBox::sorry(0L, i18n("<p>Cannot determine the 'ksniff' executable properties.<br>" \
+                               "Your installation is not correct.</p>"));
+    return -1;
+  }
+
+  if ((S_ISUID & statbuf.st_mode) != S_ISUID)
+  {
+    KMessageBox::sorry(0L, i18n("<p>The 'ksniff' executable needs root privileges to capture packets.<br>" \
+                               "Your installation is not correct.</p>"));
+    return -1;
+  }
+
   // register ourselves as a dcop client
   app.dcopClient()->registerAs(app.name(), false);
 
@@ -80,14 +102,13 @@ int main(int argc, char **argv)
       mainWidget = new KSniffer();
       app.setMainWidget( mainWidget );
       mainWidget->show();
-      args->clear();
     }
     else
     {
       int i = 0;
       for (; i < args->count(); i++)
       {
-        KSniffer *mainWidget = new KSniffer();
+        mainWidget = new KSniffer();
         mainWidget->show();
         mainWidget->load(args->url(i));
       }
