@@ -69,7 +69,7 @@ QString NetworkDevice::HWaddr2String( char *hwaddr )
 
   for (i=0; i<6; i++, hwaddr++) {
     int v = (*hwaddr & 0xff);
-    QString num = QString("%1").arg(v,0,16);
+    QString num = QString("%1").arg(v,0,16).upper();
     if (num.length() < 2)
       num.prepend("0");
     if (i>0)
@@ -83,6 +83,8 @@ void NetworkDevice::detect()
 {
     QString upMessage(   i18n("State of network card is connected",    "Up") );
     QString downMessage( i18n("State of network card is disconnected", "Down") );
+    QStringList macaddr;
+    bool duplicatedMacAddress;    // true if the MAC address is duplicated
 
     m_netDeviceList->setAutoDelete(true);
     m_netDeviceList->clear();
@@ -161,6 +163,7 @@ void NetworkDevice::detect()
           else
              tmp->m_strNetmask = i18n("Unknown");
 
+          duplicatedMacAddress = false;  // initialize the condition
           ifcopy=*ifr;
           result=-1; // if none of the two #ifs below matches, ensure that result!=0 so that "Unknown" is returned as result
 #ifdef SIOCGIFHWADDR
@@ -169,20 +172,38 @@ void NetworkDevice::detect()
           {
             char *n = &ifcopy.ifr_ifru.ifru_hwaddr.sa_data[0];
             tmp->m_strHWaddr = HWaddr2String(n);
+            QStringList::Iterator it = macaddr.begin();
+            while ((it != macaddr.end()) && (!duplicatedMacAddress))
+            {
+              duplicatedMacAddress = (tmp->m_strHWaddr == *it);
+              ++it;
+            }
           }
 #elif defined SIOCGENADDR
           result=ioctl(sockfd,SIOCGENADDR,&ifcopy);
           if (result==0)
           {
             char *n = &ifcopy.ifr_ifru.ifru_enaddr[0];
-            tmp->HWaddr = HWaddr2String(n);
+            tmp->m_strHWaddr = HWaddr2String(n);
+            QStringList::Iterator it = macaddr.begin();
+            while ((it != macaddr.end()) && (!duplicatedMacAddress))
+            {
+              duplicatedMacAddress = (tmp->m_strHWaddr == *it);
+              ++it;
+            }
           }
 #elif defined SIOCGIFMAP
           result=ioctl(sockfd,SIOCGIFMAP,&ifcopy);
           if (result==0)
           {
             char *n=&ifcopy.ifr_ifru.ifru_data[0];
-            tmp->HWaddr = HWaddr2String(n);
+            tmp->m_strHWaddr = HWaddr2String(n);
+            QStringList::Iterator it = macaddr.begin();
+            while ((it != macaddr.end()) && (!duplicatedMacAddress))
+            {
+              duplicatedMacAddress = (tmp->m_strHWaddr == *it);
+              ++it;
+            }
           }
 #endif
           if (result!=0)
@@ -191,15 +212,19 @@ void NetworkDevice::detect()
           }
 
           m_hasDevices = true;
-          m_netDeviceList->append(tmp);
-          kdDebug() << "**********************************" << endl;
-          kdDebug() << "- name: " << tmp->m_strName << endl;
-          kdDebug() << "- address: " << tmp->m_strAddress << endl;
-          kdDebug() << "- HW address: " << tmp->m_strHWaddr << endl;
-          kdDebug() << "- netmask: " << tmp->m_strNetmask << endl;
-          kdDebug() << "- state: " << tmp->m_strState << endl;
-          kdDebug() << "- type: " << tmp->m_strType << endl;
-          kdDebug() << endl;
+          if (!duplicatedMacAddress)
+          {
+            m_netDeviceList->append(tmp);
+            macaddr << tmp->m_strHWaddr;
+            kdDebug() << "**********************************" << endl;
+            kdDebug() << "- name: " << tmp->m_strName << endl;
+            kdDebug() << "- address: " << tmp->m_strAddress << endl;
+            kdDebug() << "- HW address: " << tmp->m_strHWaddr << endl;
+            kdDebug() << "- netmask: " << tmp->m_strNetmask << endl;
+            kdDebug() << "- state: " << tmp->m_strState << endl;
+            kdDebug() << "- type: " << tmp->m_strType << endl;
+            kdDebug() << endl;
+          }
           break;
         }
 
