@@ -153,6 +153,9 @@ void PacketManager::setFrameNumber( const long& num )
   m_packet.setFrameType( frameType );
   m_packet.setFrameHeaderLength( frameLength );
   m_packet.setPacket( pPacket, packetHeader );
+
+  // assign the packet length
+  m_packetSize = packetHeader.caplen;
 }
 
 
@@ -395,6 +398,11 @@ ptrPacketType PacketManager::getPacket()
 }
 
 
+int PacketManager::packetSize() const
+{
+  return m_packetSize;
+}
+
 void PacketManager::clearList()
 {
   m_bPacketAvailable = false;
