@@ -67,6 +67,7 @@ public:
   int getFrameHType();
   int getFrameHLength() const;
   ptrPacketType getPacket();
+  int packetSize() const;
 
   /**
    * Clean the packet vector.
@@ -115,6 +116,7 @@ private:
 
   QString m_strFilePath;
   bool m_bPacketAvailable;
+  int m_packetSize;
 
 private:
   void setHeaderData(pcap_t *pHandler, int &frameType, int &hdrLen);
