@@ -24,26 +24,10 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <pcap.h>
-
-#if     defined(__i386__) \
-        || defined(__x86_64__) \
-        || defined(__alpha__) \
-        || (defined(__mips__) && (defined(MIPSEL) || defined (__MIPSEL__)))
-#define BYTE_ORDER_LITTLE_ENDIAN
-#elif   defined(__mc68000__) \
-        || defined (__sparc__) \
-        || defined (__sparc) \
-        || defined (__PPC__) \
-        || (defined(__mips__) && (defined(MIPSEB) || defined (__MIPSEB__)))
-#define BYTE_ORDER_BIG_ENDIAN
-#else
-# error can not find the byte order for this architecture
-#endif
+#include <endian.h>
 
 // Max packet dimention
 #define IPMAX   65535
-//<--- FROM THIS VALUE DEPENDS THE KSNIFFER CRASH. A TOO HIGH VALUE TAKE TOO MUCH MEMORY AND KSNIFFER CRASHES...
-//#define IPMAX   1000
 #define HDRMAX  64
 #define PKTMAX  (IPMAX+HDRMAX)
 
@@ -53,14 +37,12 @@
 // IP header structure
 struct IpHdr
 {
-#if defined(BYTE_ORDER_LITTLE_ENDIAN)
+#if __BYTE_ORDER == __LITTLE_ENDIAN
     u_int8_t    ihl:4,
                 version:4;
-#elif defined (BYTE_ORDER_BIG_ENDIAN)
+#elif __BYTE_ORDER == __BIG_ENDIAN
     u_int8_t    version:4,
                 ihl:4;
-#else
-#error  "Please, edit Makefile and add -DBYTE_ORDER_(BIG|LITTLE)_ENDIAN"
 #endif
     u_int8_t     tos;
     u_int16_t    tot_len;
@@ -89,14 +71,12 @@ struct TcpHdr
     u_int16_t    th_dport;               // destination port
     u_int32_t    th_seq;                 // sequence number
     u_int32_t    th_ack;                 // acknowledgement number
-#if defined (BYTE_ORDER_LITTLE_ENDIAN)
+#if __BYTE_ORDER == __LITTLE_ENDIAN
     u_int8_t    th_x2:4,                // (unused)
                 th_off:4;               // data offset
-#elif defined (BYTE_ORDER_BIG_ENDIAN)
+#elif __BYTE_ORDER == __BIG_ENDIAN
     u_int8_t    th_off:4,               // data offset
                 th_x2:4;                // (unused)
-#else
-#error  "Please, edit Makefile and add -DBYTE_ORDER_(BIG|LITTLE)_ENDIAN"
 #endif
     u_int8_t    th_flags;
     u_int16_t   th_win;                 // window
