@@ -96,8 +96,12 @@ QString ArpProtocol::senderMacAddress() const
   struct ArpHdr *arp = (struct ArpHdr*) ( (ptrPacketType)m_packet + m_length );
   unsigned char *x = (unsigned char *) (&arp->ar_sha);
 
-  return QString("%1:%2:%3:%4:%5:%6").arg(x[0], 0, 16).arg(x[1], 0, 16).
-      arg(x[2], 0, 16).arg(x[3], 0, 16).arg(x[4], 0, 16).arg(x[5], 0, 16);
+  QString mac = QString("%1:%2:%3:%4:%5:%6").arg(x[0], 2, 16).arg(x[1], 2, 16).
+    arg(x[2], 2, 16).arg(x[3], 2, 16).arg(x[4], 2, 16).arg(x[5], 2, 16).upper();
+
+  mac.replace(" ", "0");
+
+  return mac;
 }
 
 
@@ -117,8 +121,11 @@ QString ArpProtocol::targetMacAddress() const
   struct ArpHdr *arp = (struct ArpHdr*) ( (ptrPacketType)m_packet + m_length );
   unsigned char *x = (unsigned char *) (&arp->ar_tha);
 
-  return QString("%1:%2:%3:%4:%5:%6").arg(x[0], 0, 16).arg(x[1], 0, 16).
-      arg(x[2], 0, 16).arg(x[3], 0, 16).arg(x[4], 0, 16).arg(x[5], 0, 16);
+  QString mac = QString("%1:%2:%3:%4:%5:%6").arg(x[0], 2, 16).arg(x[1], 2, 16).arg(x[2], 2, 16).
+      arg(x[3], 2, 16).arg(x[4], 2, 16).arg(x[5], 2, 16).upper();
+  mac.replace(" ", "0");
+
+  return mac;
 }
 
 
