@@ -151,7 +151,8 @@ QStringList IcmpProtocol::headerLines() const
     list << "*open";
     list << i18n("IP information:");
     ipList = ip.headerLines();
-    for ( QStringList::Iterator it = ipList.begin(); it != ipList.end(); ++it ) {
+    for ( QStringList::Iterator it = ipList.begin(); it != ipList.end(); ++it )
+    {
       list << *it;
     }
     list << "*close";
