@@ -27,7 +27,7 @@
 #include "icmp-protocol.h"
 #include "../packet.h"
 
-ProtocolManager::ProtocolManager(ptrPacketType packet, u_int8_t proto)
+ProtocolManager::ProtocolManager(ptrPacketType packet, u_int8_t proto, ProtocolNameList *pnl)
 {
   m_packet = (Packet *) packet;
   struct IpHdr *ip = (struct IpHdr*) (packet + m_packet->frameHeaderLength());
@@ -37,14 +37,15 @@ ProtocolManager::ProtocolManager(ptrPacketType packet, u_int8_t proto)
 
   m_packet = (Packet *) p;
   m_proto = proto;
+  m_protocolNameList = pnl;
 }
 
 
 QStringList ProtocolManager::headerLines() const
 {
   IcmpProtocol icmp(m_packet);
-  TcpProtocol  tcp(m_packet);
-  UdpProtocol  udp(m_packet);
+  TcpProtocol  tcp(m_packet, m_protocolNameList);
+  UdpProtocol  udp(m_packet, m_protocolNameList);
   QStringList list;
 
   if (m_packet)
