@@ -26,11 +26,12 @@ class QStringList;
 class QString;
 
 #include "../packetstructures.h"
+#include "protocolnamelist.h"
 
 class ProtocolManager
 {
 public:
-  ProtocolManager(ptrPacketType packet, u_int8_t proto);
+  ProtocolManager(ptrPacketType packet, u_int8_t proto, ProtocolNameList *pnl);
 
   QStringList headerLines() const;
   QString getProtocol() const;
@@ -38,6 +39,7 @@ public:
 private:
   Packet *m_packet;
   u_int8_t m_proto;
+  ProtocolNameList *m_protocolNameList;
 };
 
 #endif
