@@ -26,13 +26,14 @@
 #include <klocale.h>
 
 #include "tcp-protocol.h"
-#include "protocolname.h"
+#include "protocolnamelist.h"
 #include "../packet.h"
 #include "../packetstructures.h"
 
-TcpProtocol::TcpProtocol(Packet *packet)
+TcpProtocol::TcpProtocol(Packet *packet, ProtocolNameList *pnl)
 {
   m_packet = packet;
+  m_protocolNameList = pnl;
 }
 
 
@@ -122,13 +123,13 @@ QStringList TcpProtocol::headerLines() const
   QStringList list;
   QString protocol;
 
-  protocol = ProtocolName::detectProtocol( sourcePort() );
+  protocol = m_protocolNameList->detectProtocol( sourcePort() );
   if ( protocol.isEmpty() )
     list << i18n("TCP protocol field", "Source port: %1").arg( sourcePort() );
   else
     list << i18n("TCP protocol field", "Source port: %1 (%2)").arg( sourcePort() ).arg( protocol );
 
-  protocol = ProtocolName::detectProtocol( destinationPort() );
+  protocol = m_protocolNameList->detectProtocol( destinationPort() );
   if ( protocol.isEmpty() )
     list << i18n("TCP protocol field", "Destination port: %1").arg( destinationPort() );
   else
