@@ -22,6 +22,7 @@
 #define TCPPROTOCOL_H
 
 class Packet;
+class ProtocolNameList;
 class QString;
 class QStringList;
 
@@ -30,7 +31,7 @@ class QStringList;
 class TcpProtocol
 {
 public:
-  TcpProtocol(Packet *packet);
+  TcpProtocol(Packet *packet, ProtocolNameList *pnl);
 
   uint16_t sourcePort() const;
   uint16_t destinationPort() const;
@@ -44,6 +45,7 @@ public:
 
 private:
   Packet *m_packet;
+  ProtocolNameList *m_protocolNameList;
 };
 
 #endif
