@@ -25,12 +25,14 @@
 #include <klocale.h>
 
 #include "udp-protocol.h"
+#include "protocolnamelist.h"
 #include "../packet.h"
 #include "../packetstructures.h"
 
-UdpProtocol::UdpProtocol(Packet *packet)
+UdpProtocol::UdpProtocol(Packet *packet, ProtocolNameList *pnl)
 {
   m_packet = packet;
+  m_protocolNameList = pnl;
 }
 
 
@@ -69,9 +71,20 @@ u_int16_t UdpProtocol::checksum() const
 QStringList UdpProtocol::headerLines() const
 {
   QStringList list;
+  QString protocol;
+
+  protocol = m_protocolNameList->detectProtocol( sourcePort() );
+  if ( protocol.isEmpty() )
+    list << i18n("UDP protocol field", "Source port: %1").arg( sourcePort() );
+  else
+    list << i18n("UDP protocol field", "Source port: %1 (%2)").arg( sourcePort() ).arg( protocol );
+
+  protocol = m_protocolNameList->detectProtocol( destinationPort() );
+  if ( protocol.isEmpty() )
+    list << i18n("UDP protocol field", "Destination port: %1").arg( destinationPort() );
+  else
+    list << i18n("UDP protocol field", "Destination port: %1 (%2)").arg( destinationPort() ).arg( protocol );
 
-  list << i18n("UDP protocol field", "Source port: %1").arg( sourcePort() );
-  list << i18n("UDP protocol field", "Destination port: %1").arg( destinationPort() );
   list << i18n("UDP protocol field", "Length: %1").arg( length() );
   list << i18n("UDP protocol field", "Checksum: 0x%1").arg( checksum(), 0, 16 );
 
