@@ -22,6 +22,7 @@
 #define UDPPROTOCOL_H
 
 class Packet;
+class ProtocolNameList;
 class QStringList;
 
 #include <netinet/in.h>
@@ -29,7 +30,7 @@ class QStringList;
 class UdpProtocol
 {
   public:
-    UdpProtocol(Packet *packet);
+    UdpProtocol(Packet *packet, ProtocolNameList *pnl);
 
     u_int16_t sourcePort() const;
     u_int16_t destinationPort() const;
@@ -39,6 +40,7 @@ class UdpProtocol
 
   private:
     Packet *m_packet;
+    ProtocolNameList *m_protocolNameList;
 };
 
 #endif
