@@ -261,17 +261,23 @@ void Sniffer::startSniffingInterface()
 
   m_packetsTotalSize = 24;
   m_pcapfp = NULL;
+
+  // when you start sniffing the GUI read ksniffer.pcap, but it's not created untill packets doesn't arrive
+  // so it's not a real problem if m_pcapfp is NULL... the loop will not be infinite and than Sniffer class
+  // inherits by QThread so the GUI will not freeze
   while (m_pcapfp == NULL)
   {
     m_pcapfp = pcap_open_offline( m_strTmpFilePath.ascii(), errbuf );
     sleep(1);
   }
-  /*if ( m_pcapfp == NULL )
+
+  // an error occurred
+  if ( m_pcapfp == NULL )
   {
     kdDebug() << "Error opening libpcap: " << errbuf << endl;
     pcap_close( m_pcapfp );
     return;
-  }*/
+  }
 #ifdef MUST_DO_SELECT
   m_pcap_fd = pcap_fileno(m_pcapfp);
 #endif
